/*
 * ModeShape (http://www.modeshape.org)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.modeshape.common.function;

/**
 * Represents an operation that accepts a single input argument and returns no result. Unlike most other functional interfaces,
 * Consumer is expected to operate via side-effects.
 *
 * @author Randall Hauch (rhauch@redhat.com)
 * @param <T> - the type of the input to the function
 */
public interface Consumer<T> {

    /**
     * Performs this operation on the given argument.
     * 
     * @param t the value to consume
     */
    void accept( T t );

}
